{% load static %}
<!DOCTYPE html>
<html>

    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>{% block title %}{{request.site.name}}{% endblock %}</title>
        <link rel="stylesheet" href="{% static 'css/bootstrap.min.css' %}">
        <link rel="stylesheet" href="{% static 'css/font-awesome.min.css' %}" type="text/css" media="screen">
        <link rel="stylesheet" href="{% static 'css/bootstrap-social.css' %}" type="text/css" media="screen">

        {% block styles %}{% endblock %}
        {% block head %}{% endblock %}
    </head>

    <body>
        {% include "navbar.inc.html" %}

        <div class="{% block container-css %}container{% endblock %}">
            {% include "messages.inc.html" %}

            <div class="content">
                {% block content %}{% endblock %}
            </div>
        </div>
        {% block footer %}
        {% include "footer.inc.html" %}
        {% endblock %}
        <script type="text/javascript" src="{% static 'js/jquery-3.6.0.slim.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'js/popper.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'js/bootstrap.min.js' %}"></script>
        {% block javascript %}{% endblock %}
    </body>

</html>
